@@ -58,8 +58,8 @@ jstor_convert_to_file <- function(in_paths, chunk_number, out_path, fun,
   if (any(!is_ok)) {
 
     # find error-id
-    error_ids <- data_frame(id = seq_along(is_ok),
-                            is_ok = is_ok) %>%
+    error_ids <- tibble::tibble(id = seq_along(is_ok),
+                                is_ok = is_ok) %>%
       dplyr::filter(!is_ok) %>%
       dplyr::select(-is_ok)
 
